% Simple numerical integration to simulate the magnetic field of
% a cylindrical pickup magnet. An uniformly distributed
% circle of 'magnetic charge' is used to model the top surface
% of the cylindrical magnet
clear all
clc

% assuming an uniform magnetic distribution
sigma = 1;
% the coordinate origin is fixed at (0,0,0)
x0 = 0;
y0 = 0;
z0 = 0;
% the magnetic field is measured at 5 mm above the
% surface of the cylindrical magnet, (0,0,5)
y1 = 0;
x1 = 0;
z1 = 5.0;

Bz = []; % empty storage array for the magnetic field values
X = [];  % empty storage array for the displacement values

% the magnetic field is measured when moving with 1 mm horizontal
% increments across the cylindrical magnet (from -15 mm to + 15 mm)
for x1 = -15:1:15
% the integration is done over a circular top surface with a radius of 6.5 mm
Z = dblquad(@(r,p)  (sigma*z1.*r)./( ( (x1 - (x0 - r.*cos(p))).^2 + (y1 - (y0 - r.*sin(p))).^2 + (z1 - z0)^2 ).^(3/2) ) ,0,6.5,0,2*pi);
Bz = [Bz Z];
X = [X x1];
end;

% plot the results
plot(X,Bz)
